# Table of Contents

- [setup-in-apptio](<./setup-in-apptio.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Setup in Apptio](<./Setup-in-Apptio.md>)
  - [Procedure](<./Setup-in-Apptio/Procedure.md>)
  - [Apptio Service User Setup](<./Setup-in-Apptio/Apptio-Service-User-Setup.md>)
  - [Minimum Required Permissions](<./Setup-in-Apptio/Minimum-Required-Permissions.md>)
